@@ -11,6 +11,7 @@ import (
 	k8serr "k8s.io/apimachinery/pkg/api/errors"
 	"k8s.io/apimachinery/pkg/types"
 
+	liberr "github.com/konveyor/controller/pkg/error"
 	migapi "github.com/konveyor/mig-controller/pkg/apis/migration/v1alpha1"
 	migpods "github.com/konveyor/mig-controller/pkg/pods"
 	"github.com/pkg/errors"
@@ -127,8 +128,7 @@ func (t *Task) createStagePods(client k8sclient.Client, stagePods StagePodList)
 	counter := 0
 	existingPods, err := t.listStagePods(client)
 	if err != nil {
-		log.Trace(err)
-		return counter, err
+		return counter, liberr.Wrap(err)
 	}
 
 	for _, stagePod := range stagePods {
@@ -137,7 +137,7 @@ func (t *Task) createStagePods(client k8sclient.Client, stagePods StagePodList)
 		}
 		err := client.Create(context.TODO(), &stagePod.Pod)
 		if err != nil && !k8serr.IsAlreadyExists(err) {
-			return 0, err
+			return 0, liberr.Wrap(err)
 		}
 		counter++
 	}
@@ -150,18 +150,15 @@ func (t *Task) listStagePods(client k8sclient.Client) (StagePodList, error) {
 	options := k8sclient.MatchingLabels(t.stagePodLabels())
 	err := client.List(context.TODO(), options, &podList)
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	resourceLimitMapping, err := buildResourceLimitMapping(t.sourceNamespaces(), client)
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	stagePodImage, err := t.getStagePodImage(client)
 	if err != nil {
-		log.Trace(err)
-		return nil, err
+		return nil, liberr.Wrap(err)
 	}
 	return BuildStagePods(t.stagePodLabels(), t.getPVCs(), &podList.Items, stagePodImage, resourceLimitMapping), nil
 }
@@ -171,14 +168,11 @@ func (t *Task) getStagePodImage(client k8sclient.Client) (string, error) {
 	clusterConfigRef := types.NamespacedName{Name: migapi.ClusterConfigMapName, Namespace: migapi.VeleroNamespace}
 	err := client.Get(context.TODO(), clusterConfigRef, clusterConfig)
 	if err != nil {
-		log.Trace(err)
-		return "", err
+		return "", liberr.Wrap(err)
 	}
 	stagePodImage, ok := clusterConfig.Data[migapi.StagePodImageKey]
 	if !ok {
-		err := errors.Errorf("configmap key not found: %v", migapi.StagePodImageKey)
-		log.Trace(err)
-		return "", err
+		return "", liberr.Wrap(errors.Errorf("configmap key not found: %v", migapi.StagePodImageKey))
 	}
 	return stagePodImage, nil
 }
@@ -187,8 +181,7 @@ func (t *Task) ensureStagePodsFromOrphanedPVCs() error {
 	stagePods := StagePodList{}
 	client, err := t.getSourceClient()
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	existingStagePods, err := t.listStagePods(client)
@@ -216,13 +209,11 @@ func (t *Task) ensureStagePodsFromOrphanedPVCs() error {
 
 	resourceLimitMapping, err := buildResourceLimitMapping(t.sourceNamespaces(), client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	stagePodImage, err := t.getStagePodImage(client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	for _, ns := range t.sourceNamespaces() {
@@ -256,8 +247,7 @@ func (t *Task) ensureStagePodsFromOrphanedPVCs() error {
 
 	created, err := t.createStagePods(client, stagePods)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	if created > 0 {
@@ -279,32 +269,27 @@ func (t *Task) ensureStagePodsFromOrphanedPVCs() error {
 func (t *Task) ensureStagePodsFromTemplates() error {
 	client, err := t.getSourceClient()
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	podTemplates, err := migpods.ListTemplatePods(client, t.sourceNamespaces())
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	resourceLimitMapping, err := buildResourceLimitMapping(t.sourceNamespaces(), client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	stagePodImage, err := t.getStagePodImage(client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	stagePods := BuildStagePods(t.stagePodLabels(), t.getPVCs(), &podTemplates, stagePodImage, resourceLimitMapping)
 
 	created, err := t.createStagePods(client, stagePods)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	if created > 0 {
@@ -328,18 +313,15 @@ func buildResourceLimitMapping(namespaces []string, client k8sclient.Client) (ma
 		limitRangeList := corev1.LimitRangeList{}
 		err := client.List(context.TODO(), k8sclient.InNamespace(ns), &limitRangeList)
 		if err != nil {
-			log.Trace(err)
-			return nil, err
+			return nil, liberr.Wrap(err)
 		}
 		memVal, err := resource.ParseQuantity(defaultMemory)
 		if err != nil {
-			log.Trace(err)
-			return nil, err
+			return nil, liberr.Wrap(err)
 		}
 		cpuVal, err := resource.ParseQuantity(defaultCPU)
 		if err != nil {
-			log.Trace(err)
-			return nil, err
+			return nil, liberr.Wrap(err)
 		}
 		for _, limitRange := range limitRangeList.Items {
 			for _, limit := range limitRange.Spec.Limits {
@@ -381,34 +363,29 @@ func parseResourceLimitMapping(ns string, mapping map[string]map[string]resource
 func (t *Task) ensureStagePodsFromRunning() error {
 	client, err := t.getSourceClient()
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	stagePods := StagePodList{}
 	resourceLimitMapping, err := buildResourceLimitMapping(t.sourceNamespaces(), client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	stagePodImage, err := t.getStagePodImage(client)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	for _, ns := range t.sourceNamespaces() {
 		podList := corev1.PodList{}
 		err := client.List(context.TODO(), k8sclient.InNamespace(ns), &podList)
 		if err != nil {
-			log.Trace(err)
-			return err
+			return liberr.Wrap(err)
 		}
 		stagePods.merge(BuildStagePods(t.stagePodLabels(), t.getPVCs(), &podList.Items, stagePodImage, resourceLimitMapping)...)
 	}
 
 	created, err := t.createStagePods(client, stagePods)
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 
 	if created > 0 {
@@ -430,7 +407,7 @@ func (t *Task) ensureStagePodsFromRunning() error {
 func (t *Task) ensureStagePodsStarted() (report PodStartReport, err error) {
 	client, err := t.getSourceClient()
 	if err != nil {
-		log.Trace(err)
+		err = liberr.Wrap(err)
 		return
 	}
 	hasHealthyClaims := func(pod *corev1.Pod) (healthy bool) {
@@ -449,7 +426,7 @@ func (t *Task) ensureStagePodsStarted() (report PodStartReport, err error) {
 			if err != nil {
 				healthy = false
 				if !k8serr.IsNotFound(err) {
-					log.Trace(err)
+					err = liberr.Wrap(err)
 					return
 				}
 				report.reasons = append(
@@ -504,8 +481,7 @@ func (t *Task) ensureStagePodsStarted() (report PodStartReport, err error) {
 func (t *Task) ensureStagePodsDeleted() error {
 	clients, err := t.getBothClients()
 	if err != nil {
-		log.Trace(err)
-		return err
+		return liberr.Wrap(err)
 	}
 	options := k8sclient.MatchingLabels(t.Owner.GetCorrelationLabels())
 	for _, client := range clients {
@@ -518,8 +494,7 @@ func (t *Task) ensureStagePodsDeleted() error {
 			// Delete
 			err := client.Delete(context.TODO(), &pod)
 			if err != nil && !k8serr.IsNotFound(err) {
-				log.Trace(err)
-				return err
+				return liberr.Wrap(err)
 			}
 			log.Info(
 				"Stage pod deleted.",
@@ -537,8 +512,7 @@ func (t *Task) ensureStagePodsDeleted() error {
 func (t *Task) ensureStagePodsTerminated() (bool, error) {
 	clients, err := t.getBothClients()
 	if err != nil {
-		log.Trace(err)
-		return false, err
+		return false, liberr.Wrap(err)
 	}
 
 	terminatedPhases := map[corev1.PodPhase]bool{
